@@ -176,18 +176,16 @@ class Reporter(object):
             <script>
                 function copyFailedTestCase(){
                     document.getElementById("failed_testcase_names").style.display="none";
-                    if (%s === 1){
-                        document.getElementById("copy_status_info").innerHTML = "<font style='padding-left: 56' color=darkorange>Copied 1 TestCase</font>";
-                    } else if(%s > 1){
-                        document.getElementById("copy_status_info").innerHTML = "<font style='padding-left: 56' color=darkorange>Copied %s TestCases</font>";
-                    }
+                    
+                    document.getElementById("copy_status_info").innerHTML = "<font color=#DC3912>Copied</font>";
+                    
                     setTimeout(function(){
                         document.getElementById("copy_status_info").innerHTML = "";
                         document.getElementById("failed_testcase_names").style.display="block";
-                    }, 2000);
+                    }, 1000);
                 }
             </script>
-            """ % (len(failed_cases), len(failed_cases), failed_cases_count)
+            """
 
             # refresh_string = "<meta http-equiv=\"Refresh\" content=\"60\" />"
 
@@ -219,7 +217,7 @@ class Reporter(object):
             <table align='center'>
                 <tr>
                     <td>
-                        <div id='chart_div' style="min-width: 560px; height: 330px; migin: 10 auto"></div>
+                        <div id='chart_div' style="min-width: 580px; height: 360px; migin: 10 auto"></div>
                     </td>
                     <td>
                         <table border='0' class="table table-hover">
@@ -252,12 +250,12 @@ class Reporter(object):
                                 <td align='center'>%s</td>
                             </tr>
                             <tr>
-                                <th>Execution Host</th>
+                                <th>Execution Host OS</th>
                                 <td align='center'>%s</td>
                             </tr>
                             <tr>
                                 <th>Test Framework</th>
-                                <td align='center'>lintest==%s</td>
+                                <td align='center'>lintest %s</td>
                             </tr>
                         </table>
                     </td>
@@ -293,9 +291,9 @@ class Reporter(object):
             # generate the drop down list for all the different tags
             html_drop_down_list = """
             <br>
-            <table border='0' align='center' width='920'>
+            <table border='0' align='center' width='950'>
                 <tr>
-                    <td width='265'><font style='color: black; font-size: 18'>Filter TestCases By Package: </font></td>
+                    <td width='285'><font style='color: black; font-size: 18; margin-left: -30'>Filter TestCases By Package: </font></td>
                     <td>
             """
             report_file_handler.write(html_drop_down_list)
@@ -320,7 +318,9 @@ class Reporter(object):
                     str_failed_testcase_names += failed_testcase.__class__.__name__ + " "
 
                 str_failed_testcases = """
-                <button style='background-color: darkorange; border-radius: 10px;' id="failed_testcase_names" data-clipboard-text="%s" onclick="copyFailedTestCase()">
+                <button style='background-color: #DC3912; border: none; border-radius: 10px;' 
+                id="failed_testcase_names" class='failed_testcase_names'
+                 data-clipboard-text="%s" onclick="copyFailedTestCase()">
                     <font color='white'>Copy Failed Case Names</font>
                 </button>
                 <script>
@@ -340,18 +340,17 @@ class Reporter(object):
                 <table class='table table-hover' border='0'>
                     <tr id='all_failed_test_cases' style='color:#DC3912; background-color: whitesmoke;'>
                         <th width='120'>
-                               TestCaseID
+                               TestCaseId
                         </th>
-                        <th width='710'>
-                                <font id='num_fail'>%s Test%s Failed</font>
+                        <th width='700'>
+                                <font id='num_fail'>%s</font><font style='margin-left: 8px;'>Failed Log</font>
                         </th>
                         <th width='200'>
                             Duration(Seconds)
                         </th>
                     </tr>
                 """ % (
-                    failed_cases_count,
-                    "Cases" if failed_cases_count > 1 else "Case"
+                    failed_cases_count
                 )
 
                 report_file_handler.write(failed_testcase_table)
@@ -381,14 +380,13 @@ class Reporter(object):
                     report_file_handler.write(
                         "<td width='125' align='center' style='word-break:break-all;no-wrap:no-wrap'>")
                     report_file_handler.write(
-                        "<a title='Click to go to test center' href='https://testcenter.lintest.com/testlink/linkto.php?tprojectPrefix=ET&item=testcase&id=ET-%s'><font color='#DC3912'>" % getattr(
+                        "<a title='Click to go to test center' href='https://testcenter.lintest.com/testlink/linkto.php?tprojectPrefix=ET&item=testcase&id=ET-%s'><font color='#333'>" % getattr(
                             failed_testcase, "testcase_id", "None"))
                     report_file_handler.write("%s" % getattr(failed_testcase, "testcase_id", "None"))
-                    report_file_handler.write("</font></a>")
-                    report_file_handler.write("</td>")
+                    report_file_handler.write("</font></a></td>")
 
                     testcase_information = """
-                        <td width='650'style='word-break:break-all'>
+                        <td width='710'style='word-break:break-all'>
                         <a  href='%s'>
                             <font color='#333'>
                                 %s
@@ -459,18 +457,17 @@ class Reporter(object):
                 <table class='table table-hover' border='0'>
                     <tr id='all_passed_test_cases' style='color:#3366CC; background-color: whitesmoke;'>
                         <th width='120'>
-                            TestCaseID
+                            TestCaseId
                         </th>
-                        <th width='710'>
-                                <font id='num_pass'>%s  Test%s Passed</font>
+                        <th width='700'>
+                            <font id='num_pass'>%s</font><font style='margin-left: 8px;'>Passed Log</font>
                         </th>
                         <th width='200'>
                                 Duration(Seconds)
                         </th>
                     </tr>
                 """ % (
-                    len(passed_cases),
-                    "Cases" if len(passed_cases) > 1 else "Case"
+                    len(passed_cases)
                 )
                 report_file_handler.write(passed_testcase_table)
 
@@ -492,7 +489,7 @@ class Reporter(object):
                     report_file_handler.write("</font></a>")
                     report_file_handler.write("</td>")
 
-                    report_file_handler.write("<td width='650' style='word-break:break-all'>")
+                    report_file_handler.write("<td width='710' style='word-break:break-all'>")
                     report_file_handler.write("<a title='Click to see the log & screenshot' href='")
                     report_file_handler.write(module_name)
                     report_file_handler.write(
@@ -512,7 +509,7 @@ class Reporter(object):
 
                     try:
                         report_file_handler.write(
-                            "<a title='Click to show log detail' href='%s'>        <font color='green'>&nbsp;&nbsp;Log</font> </a>" %
+                            "<a title='Click to show log detail' href='%s'>        <font color='#3366CC'>&nbsp;&nbsp;Log</font> </a>" %
                             passed_testcase.log_file_path)
                     except BaseException:
                         print(traceback.format_exc())
@@ -620,9 +617,7 @@ class Reporter(object):
 
                     option && myChart.setOption(option);
             </script>
-                            
-            <script>$(function () { $("[data-toggle='tooltip']").tooltip(); });</script>
-            
+                                
                    """ % (len(passed_cases), failed_cases_count)
 
             report_file_handler.write(echarts_str)
